@@ -11,7 +11,9 @@ from .mnist import mnist_data
 from .local_mnist import loadlocal_mnist
 from .boston_housing import boston_housing_data
 from .three_blobs import three_blobs_data
+from .multiplexer import make_multiplexer_dataset
 
 __all__ = ["iris_data", "wine_data", "autompg_data",
            "loadlocal_mnist", "mnist_data",
-           "boston_housing_data", "three_blobs_data"]
+           "boston_housing_data", "three_blobs_data",
+           "make_multiplexer_dataset"]
