@@ -179,4 +179,9 @@ class StackingCVRegressor(BaseEstimator, RegressorMixin, TransformerMixin):
             for name, step in six.iteritems(self.named_meta_regressor):
                 for key, value in six.iteritems(step.get_params(deep=True)):
                     out['%s__%s' % (name, key)] = value
+
+            for key, value in six.iteritems(super(StackingCVRegressor,
+                                            self).get_params(deep=False)):
+                out['%s' % key] = value
+
             return out
